const canvas = document.getElementById("gameCanvas");
const ctx = canvas.getContext("2d");
const startButton = document.getElementById("startButton");
const resetButton = document.getElementById("resetButton");
const scoreDisplay = document.getElementById("score");

const gridSize = 20;
const tileCount = canvas.width / gridSize;

let snake = [{ x: 10, y: 10 }];
let food = { x: 5, y: 5 };
let direction = { x: 0, y: 0 };
let score = 0;
let gameRunning = false;
let gameInterval;

function drawGame() {
  if (!gameRunning) return;

  // Clear canvas
  ctx.fillStyle = "#222";
  ctx.fillRect(0, 0, canvas.width, canvas.height);

  // Draw snake
  ctx.fillStyle = "#4CAF50";
  snake.forEach((segment) => {
    ctx.fillRect(
      segment.x * gridSize,
      segment.y * gridSize,
      gridSize,
      gridSize,
    );
  });

  // Draw food
  ctx.fillStyle = "#FF5252";
  ctx.fillRect(food.x * gridSize, food.y * gridSize, gridSize, gridSize);

  // Update score display
  scoreDisplay.textContent = score;
}

function updateSnake() {
  if (!gameRunning) return;

  // Move snake
  const head = { x: snake[0].x + direction.x, y: snake[0].y + direction.y };

  // Check collision with walls or self
  if (
    head.x < 0 ||
    head.x >= tileCount ||
    head.y < 0 ||
    head.y >= tileCount ||
    snake.some((segment) => segment.x === head.x && segment.y === head.y)
  ) {
    gameRunning = false;
    clearInterval(gameInterval); // Stop the game loop
    return;
  }

  snake.unshift(head);

  // Check if snake eats food
  if (head.x === food.x && head.y === food.y) {
    score++;
    placeFood();
  } else {
    snake.pop();
  }

  drawGame();
}

function placeFood() {
  food = {
    x: Math.floor(Math.random() * tileCount),
    y: Math.floor(Math.random() * tileCount),
  };

  // Make sure food doesn't spawn on snake
  while (
    snake.some((segment) => segment.x === food.x && segment.y === food.y)
  ) {
    food = {
      x: Math.floor(Math.random() * tileCount),
      y: Math.floor(Math.random() * tileCount),
    };
  }
}

function startGame() {
  if (gameRunning) return;
  snake = [{ x: 10, y: 10 }];
  direction = { x: 1, y: 0 }; // Start moving right
  score = 0;
  placeFood();
  gameRunning = true;
  drawGame();

  // Start the game loop to update snake position every 500ms
  gameInterval = setInterval(updateSnake, 500);
}

function resetGame() {
  gameRunning = false;
  clearInterval(gameInterval); // Stop the game loop
  startGame();
}

window.addEventListener("keydown", (e) => {
  if (!gameRunning) return;
  console.log(e.key);
  switch (e.key) {
    case "ArrowUp":
      if (direction.y === 0) direction = { x: 0, y: -1 };
      break;
    case "ArrowDown":
      if (direction.y === 0) direction = { x: 0, y: 1 };
      break;
    case "ArrowLeft":
      if (direction.x === 0) direction = { x: -1, y: 0 };
      break;
    case "ArrowRight":
      if (direction.x === 0) direction = { x: 1, y: 0 };
      break;
  }
});

startButton.addEventListener("click", startGame);
resetButton.addEventListener("click", resetGame);
